@@ -4,7 +4,6 @@
 #pragma once
 
 #include "baseline.hpp"
-#include "eof.hpp"
 #include "execution_state.hpp"
 #include "instructions_traits.hpp"
 #include "instructions_xmacro.hpp"
@@ -573,25 +572,6 @@ inline Result extcodecopy(StackTop stack, int64_t gas_left, ExecutionState& stat
     return {EVMC_SUCCESS, gas_left};
 }
 
-inline void returndataload(StackTop stack, ExecutionState& state) noexcept
-{
-    auto& index = stack.top();
-
-    if (state.return_data.size() < index)
-        index = 0;
-    else
-    {
-        const auto begin = static_cast<size_t>(index);
-        const auto end = std::min(begin + 32, state.return_data.size());
-
-        uint8_t data[32] = {};
-        for (size_t i = 0; i < (end - begin); ++i)
-            data[i] = state.return_data[begin + i];
-
-        index = intx::be::unsafe::load<uint256>(data);
-    }
-}
-
 inline void returndatasize(StackTop stack, ExecutionState& state) noexcept
 {
     stack.push(state.return_data.size());
@@ -609,36 +589,18 @@ inline Result returndatacopy(StackTop stack, int64_t gas_left, ExecutionState& s
     auto dst = static_cast<size_t>(mem_index);
     auto s = static_cast<size_t>(size);
 
-    if (is_eof_container(state.original_code))
-    {
-        auto src = state.return_data.size() < input_index ? state.return_data.size() :
-                                                            static_cast<size_t>(input_index);
-        auto copy_size = std::min(s, state.return_data.size() - src);
+    if (state.return_data.size() < input_index)
+        return {EVMC_INVALID_MEMORY_ACCESS, gas_left};
+    auto src = static_cast<size_t>(input_index);
 
-        if (const auto cost = copy_cost(s); (gas_left -= cost) < 0)
-            return {EVMC_OUT_OF_GAS, gas_left};
+    if (src + s > state.return_data.size())
+        return {EVMC_INVALID_MEMORY_ACCESS, gas_left};
 
-        if (copy_size > 0)
-            std::memcpy(&state.memory[dst], &state.return_data[src], copy_size);
+    if (const auto cost = copy_cost(s); (gas_left -= cost) < 0)
+        return {EVMC_OUT_OF_GAS, gas_left};
 
-        if (s - copy_size > 0)
-            std::memset(&state.memory[dst + copy_size], 0, s - copy_size);
-    }
-    else
-    {
-        if (state.return_data.size() < input_index)
-            return {EVMC_INVALID_MEMORY_ACCESS, gas_left};
-        auto src = static_cast<size_t>(input_index);
-
-        if (src + s > state.return_data.size())
-            return {EVMC_INVALID_MEMORY_ACCESS, gas_left};
-
-        if (const auto cost = copy_cost(s); (gas_left -= cost) < 0)
-            return {EVMC_OUT_OF_GAS, gas_left};
-
-        if (s > 0)
-            std::memcpy(&state.memory[dst], &state.return_data[src], s);
-    }
+    if (s > 0)
+        std::memcpy(&state.memory[dst], &state.return_data[src], s);
 
     return {EVMC_SUCCESS, gas_left};
 }
@@ -775,40 +737,6 @@ inline code_iterator jumpi(StackTop stack, ExecutionState& state, code_iterator
     return cond ? jump_impl(state, dst) : pos + 1;
 }
 
-inline code_iterator rjump(StackTop /*stack*/, ExecutionState& /*state*/, code_iterator pc) noexcept
-{
-    // Reading next 2 bytes is guaranteed to be safe by deploy-time validation.
-    const auto offset = read_int16_be(&pc[1]);
-    return pc + 3 + offset;  // PC_post_rjump + offset
-}
-
-inline code_iterator rjumpi(StackTop stack, ExecutionState& state, code_iterator pc) noexcept
-{
-    const auto cond = stack.pop();
-    return cond ? rjump(stack, state, pc) : pc + 3;
-}
-
-inline code_iterator rjumpv(StackTop stack, ExecutionState& /*state*/, code_iterator pc) noexcept
-{
-    constexpr auto REL_OFFSET_SIZE = sizeof(int16_t);
-    const auto case_ = stack.pop();
-
-    const auto max_index = pc[1];
-    const auto pc_post = pc + 1 + 1 /* max_index */ + (max_index + 1) * REL_OFFSET_SIZE /* tbl */;
-
-    if (case_ > max_index)
-    {
-        return pc_post;
-    }
-    else
-    {
-        const auto rel_offset =
-            read_int16_be(&pc[2 + static_cast<uint16_t>(case_) * REL_OFFSET_SIZE]);
-
-        return pc_post + rel_offset;
-    }
-}
-
 inline code_iterator pc(StackTop stack, ExecutionState& state, code_iterator pos) noexcept
 {
     stack.push(static_cast<uint64_t>(pos - state.analysis.baseline->executable_code().data()));
@@ -953,28 +881,6 @@ inline void swap(StackTop stack) noexcept
     a[3] = t3;
 }
 
-inline code_iterator dupn(StackTop stack, code_iterator pos) noexcept
-{
-    stack.push(stack[pos[1]]);
-    return pos + 2;
-}
-
-inline code_iterator swapn(StackTop stack, code_iterator pos) noexcept
-{
-    // TODO: This may not be optimal, see instr::core::swap().
-    std::swap(stack.top(), stack[pos[1] + 1]);
-    return pos + 2;
-}
-
-inline code_iterator exchange(StackTop stack, code_iterator pos) noexcept
-{
-    const auto n = (pos[1] >> 4) + 1;
-    const auto m = (pos[1] & 0x0f) + 1;
-    // TODO: This may not be optimal, see instr::core::swap().
-    std::swap(stack[n], stack[n + m]);
-    return pos + 2;
-}
-
 inline Result mcopy(StackTop stack, int64_t gas_left, ExecutionState& state) noexcept
 {
     const auto& dst_u256 = stack.pop();
@@ -997,67 +903,6 @@ inline Result mcopy(StackTop stack, int64_t gas_left, ExecutionState& state) noe
     return {EVMC_SUCCESS, gas_left};
 }
 
-inline void dataload(StackTop stack, ExecutionState& state) noexcept
-{
-    const auto data = state.analysis.baseline->eof_data();
-    auto& index = stack.top();
-
-    if (data.size() < index)
-        index = 0;
-    else
-    {
-        const auto begin = static_cast<size_t>(index);
-        const auto end = std::min(begin + 32, data.size());
-
-        uint8_t d[32] = {};
-        for (size_t i = 0; i < (end - begin); ++i)
-            d[i] = data[begin + i];
-
-        index = intx::be::unsafe::load<uint256>(d);
-    }
-}
-
-inline void datasize(StackTop stack, ExecutionState& state) noexcept
-{
-    stack.push(state.analysis.baseline->eof_data().size());
-}
-
-inline code_iterator dataloadn(StackTop stack, ExecutionState& state, code_iterator pos) noexcept
-{
-    const auto index = read_uint16_be(&pos[1]);
-
-    stack.push(intx::be::unsafe::load<uint256>(&state.analysis.baseline->eof_data()[index]));
-    return pos + 3;
-}
-
-inline Result datacopy(StackTop stack, int64_t gas_left, ExecutionState& state) noexcept
-{
-    const auto data = state.analysis.baseline->eof_data();
-    const auto& mem_index = stack.pop();
-    const auto& data_index = stack.pop();
-    const auto& size = stack.pop();
-
-    if (!check_memory(gas_left, state.memory, mem_index, size))
-        return {EVMC_OUT_OF_GAS, gas_left};
-
-    const auto dst = static_cast<size_t>(mem_index);
-    // TODO why?
-    const auto src = data.size() < data_index ? data.size() : static_cast<size_t>(data_index);
-    const auto s = static_cast<size_t>(size);
-    const auto copy_size = std::min(s, data.size() - src);
-
-    if (const auto cost = copy_cost(s); (gas_left -= cost) < 0)
-        return {EVMC_OUT_OF_GAS, gas_left};
-
-    if (copy_size > 0)
-        std::memcpy(&state.memory[dst], &data[src], copy_size);
-
-    if (s - copy_size > 0)
-        std::memset(&state.memory[dst + copy_size], 0, s - copy_size);
-
-    return {EVMC_SUCCESS, gas_left};
-}
-
 template <size_t NumTopics>
 inline Result log(StackTop stack, int64_t gas_left, ExecutionState& state) noexcept
 {
@@ -1096,70 +941,11 @@ inline constexpr auto callcode = call_impl<OP_CALLCODE>;
 inline constexpr auto delegatecall = call_impl<OP_DELEGATECALL>;
 inline constexpr auto staticcall = call_impl<OP_STATICCALL>;
 
-template <Opcode Op>
-Result extcall_impl(StackTop stack, int64_t gas_left, ExecutionState& state) noexcept;
-inline constexpr auto extcall = extcall_impl<OP_EXTCALL>;
-inline constexpr auto extdelegatecall = extcall_impl<OP_EXTDELEGATECALL>;
-inline constexpr auto extstaticcall = extcall_impl<OP_EXTSTATICCALL>;
-
 template <Opcode Op>
 Result create_impl(StackTop stack, int64_t gas_left, ExecutionState& state) noexcept;
 inline constexpr auto create = create_impl<OP_CREATE>;
 inline constexpr auto create2 = create_impl<OP_CREATE2>;
 
-template <Opcode Op>
-Result create_eof_impl(
-    StackTop stack, int64_t gas_left, ExecutionState& state, code_iterator& pos) noexcept;
-inline constexpr auto eofcreate = create_eof_impl<OP_EOFCREATE>;
-inline constexpr auto txcreate = create_eof_impl<OP_TXCREATE>;
-
-inline code_iterator callf(StackTop stack, ExecutionState& state, code_iterator pos) noexcept
-{
-    const auto index = read_uint16_be(&pos[1]);
-    const auto& header = state.analysis.baseline->eof_header();
-    const auto stack_size = stack.end() - state.stack_space.bottom();
-    const auto callee_type = header.get_type(state.original_code, index);
-    if (stack_size + callee_type.max_stack_increase > StackSpace::limit)
-    {
-        state.status = EVMC_STACK_OVERFLOW;
-        return nullptr;
-    }
-
-    if (state.call_stack.size() >= StackSpace::limit)
-    {
-        // TODO: Add different error code.
-        state.status = EVMC_STACK_OVERFLOW;
-        return nullptr;
-    }
-    state.call_stack.push_back(pos + 3);
-
-    const auto offset = header.code_offsets[index] - header.code_offsets[0];
-    return state.analysis.baseline->executable_code().data() + offset;
-}
-
-inline code_iterator retf(StackTop /*stack*/, ExecutionState& state, code_iterator /*pos*/) noexcept
-{
-    const auto p = state.call_stack.back();
-    state.call_stack.pop_back();
-    return p;
-}
-
-inline code_iterator jumpf(StackTop stack, ExecutionState& state, code_iterator pos) noexcept
-{
-    const auto index = read_uint16_be(&pos[1]);
-    const auto& header = state.analysis.baseline->eof_header();
-    const auto stack_size = stack.end() - state.stack_space.bottom();
-    const auto callee_type = header.get_type(state.original_code, index);
-    if (stack_size + callee_type.max_stack_increase > StackSpace::limit)
-    {
-        state.status = EVMC_STACK_OVERFLOW;
-        return nullptr;
-    }
-
-    const auto offset = header.code_offsets[index] - header.code_offsets[0];
-    return state.analysis.baseline->executable_code().data() + offset;
-}
-
 template <evmc_status_code StatusCode>
 inline TermResult return_impl(StackTop stack, int64_t gas_left, ExecutionState& state) noexcept
 {
@@ -1177,29 +963,6 @@ inline TermResult return_impl(StackTop stack, int64_t gas_left, ExecutionState&
 inline constexpr auto return_ = return_impl<EVMC_SUCCESS>;
 inline constexpr auto revert = return_impl<EVMC_REVERT>;
 
-inline TermResult returncode(
-    StackTop stack, int64_t gas_left, ExecutionState& state, code_iterator pos) noexcept
-{
-    const auto& offset = stack[0];
-    const auto& size = stack[1];
-
-    if (!check_memory(gas_left, state.memory, offset, size))
-        return {EVMC_OUT_OF_GAS, gas_left};
-
-    const auto deploy_container_index = size_t{pos[1]};
-    bytes deploy_container{state.analysis.baseline->eof_header().get_container(
-        state.original_code, deploy_container_index)};
-
-    // Append (offset, size) to data section
-    if (!append_data_section(deploy_container,
-            {&state.memory[static_cast<size_t>(offset)], static_cast<size_t>(size)}))
-        return {EVMC_OUT_OF_GAS, gas_left};
-
-    state.deploy_container = std::move(deploy_container);
-
-    return {EVMC_SUCCESS, gas_left};
-}
-
 inline TermResult selfdestruct(StackTop stack, int64_t gas_left, ExecutionState& state) noexcept
 {
     if (state.in_static_mode())
